//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1995
// 
// uAssert.h -- 
// 
// Author           : Peter A. Buhr
// Created On       : Sun Jun 11 15:48:38 1995
// Last Modified By : Peter A. Buhr
// Last Modified On : Tue Sep 12 09:51:12 2006
// Update Count     : 30
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


// This include file is not suppose to be idempotent, so there is no guard.

#undef uAssert
#warning uAssert.h and uAssert(...) deprecated : use assert.h and assert(...)

#include <assert.h>
#define	uAssert(expr) assert(expr)


// Local Variables: //
// compile-command: "gmake install" //
// End: //
